=======
Credits
=======

Development Lead
----------------

* Simon Birrer <sibirrer@gmail.com>

Contributors
------------

* Adam Amara
* Joel Akeret
* Anowar Shajib
* Daniel Gilman
* Felix A. Kuhn
* Kevin Fusshoeller
* Cyril Welschen
* Felix Mayor

SB acknowledges the support by Tommaso Treu (UCLA) and Alexandre Refregier (ETHZ) which made the development and release
of this software possible.